@@ -166,7 +166,7 @@ class SeriesTransformer:
                 for Hourly: 24, Monthly: 12, Quarterly: 4. everything else gets 1 (no seasonality assumed)
                 so pass your own values for other frequencies.
             fit_intercept (bool): Default True. Whether to fit an intercept in the model.
-            train_only (bool): Default False. Whether to fit the OLS model on the training set only.
+            train_only (bool): Default False. Whether to fit the LOESS or OLS model on the training set only.
 
         Returns:
             (Forecaster): A Forecaster object with the transformed attributes.
@@ -235,7 +235,7 @@ class SeriesTransformer:
             self.detrend_params['fvs_test'] = fvs_test
         else:
             from statsmodels.nonparametric.smoothers_lowess import lowess
-            y = fmod.y.values if not train_only else fmod.y.values[-self.test_length:]
+            y = fmod.y.values if not train_only else fmod.y.values[-fmod.test_length:]
             loess_fit = lowess(
                 y, 
                 fmod.current_xreg['t'][:len(y)], 
