@@ -33,7 +33,7 @@ class Forecaster_parent:
         metrics,
         **kwargs,
     ):
-        logging.basicConfig(filename="warnings.log", level=logging.WARNING)
+        self._logging()
         self.y = y
         self.sklearn_imports = __sklearn_imports__
         self.sklearn_estimators = __sklearn_estimators__
@@ -67,6 +67,14 @@ class Forecaster_parent:
         obj.__dict__ = copy.deepcopy(self.__dict__)
         return obj
 
+    def __getstate__(self):
+        self._logging()
+        state = self.__dict__.copy()
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+
     def _check_right_test_length_for_cis(self,cilevel):
         min_test_length = np.ceil(1/(1-cilevel))
         if self.test_length < min_test_length:
@@ -81,6 +89,9 @@ class Forecaster_parent:
                 )
             )
 
+    def _logging(self):
+        logging.basicConfig(filename="warnings.log", level=logging.WARNING)
+
     def _clear_the_deck(self):
         """ deletes the following attributes to prepare a new forecast:
             'univariate','fitted_values','regr','X','feature_importance','summary_stats','models','weights'
@@ -454,9 +465,30 @@ class Forecaster_parent:
 
         >>> f.set_grids_file('ModGrids') # expects to find a file called ModGrids.py in working directory.
         """
-        _developer_utils.descriptive_assert(isinstance(name,str),ValueError,f'name argument expected str type, got {type(name)}')
+        _developer_utils.descriptive_assert(
+            isinstance(name,str),
+            ValueError,
+            f'name argument expected str type, got {type(name)}.'
+        )
         self.grids_file = name
 
+    def _fit_normalizer(self, X, normalizer):
+        _developer_utils.descriptive_assert(
+            normalizer in self.normalizer,
+            ValueError,
+            f"normalizer must be one of {list(self.normalizer.keys())}, got {normalizer}.",
+        )
+        
+        if normalizer is None:
+            return None
+
+        scaler = self.normalizer[normalizer]()
+        scaler.fit(X)
+        return scaler
+
+    def _scale(self, scaler,X):
+        return scaler.transform(X) if scaler is not None else X
+
 def _tune_test_forecast(
     f,
     models,
